==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN activada</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN desactivada</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Blocatge de majúscules activat</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Blocatge de majúscules desactivat</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Teclat numèric activat</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Teclat numèric desactivat</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Ratolí tàctil activat</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Ratolí tàctil desactivat</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Commuta el ratolí tàctil</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Commutació d&apos;Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mode d&apos;avió activat</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mode d&apos;avió desactivat</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Silenci activat</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Silenci desactivat</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Energia equilibrada</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Estalviador d&apos;energia</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Rendiment alt</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Efectes de finestra habilitats</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Efectes de finestra inhabilitats</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Ha fallat activar els efectes de les finestres.</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN activada</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN desactivada</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Blocatge de majúscules activat</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Blocatge de majúscules desactivat</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Teclat numèric activat</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Teclat numèric desactivat</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Ratolí tàctil activat</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Ratolí tàctil desactivat</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Commuta el ratolí tàctil</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Commutació d&apos;Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mode d&apos;avió activat</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mode d&apos;avió desactivat</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Silenci activat</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Silenci desactivat</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Energia equilibrada</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Estalviador d&apos;energia</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Rendiment alt</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Efectes de finestra habilitats</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Efectes de finestra inhabilitats</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Ha fallat activar els efectes de les finestres.</translation>
    </message>
</context>
</TS>
